| TidalCharacteristics | R Documentation |
Calculates the characteristics of observed tidal water levels. Wrapper of the functions extrema, IT and IF. Also works on time series with gaps.
TidalCharacteristics(
h,
h0 = h$h0,
T2 = 5 * 60 * 60,
hoffset = 0,
filtconst = 1,
dtMax = 15,
unit = "mins",
Tavg = 12.4 * 60,
removegaps = c("All", "Split", "None")
)
h |
Water level time series. data frame with time and h column |
h0 |
Reference level, either single valued or vector with dimension corresponding to h |
T2 |
'Lower' bound on half the quasi period, but higher than expected stagnant phase; default = 5h |
hoffset |
Offset level, to prevent spurious maxima generation due to small fluctuations |
filtconst |
Filtering constant for smoothing the time series |
dtMax |
Maximum accepted time interval in a continuous series. Bigger time intervals are considered to be gaps |
unit |
Unit of dtMax, Tavg |
Tavg |
Average period of time series |
removegaps |
Method to remove gaps in time series from inundation times and dry times. See |
An object of class Tides, i.e. a list containing:
HL |
Data frame with extrema |
h |
original water level data frame with additional attributes |
gaps |
a data frame containing start and end times of gaps in the series |
IF |
inundation frequency of the reference level |
ITs |
inundation times at the reference level |
DTs |
dry times at the reference level |
h0 |
reference level |
N |
Total number of cycles in time span |
Tom Cox <tom.cox@uantwerp.be>, Lennert Schepers <lennert.schepers@uantwerp.be>
extrema, IT, plot.Tides
TC <- TidalCharacteristics(waterlevels, filtconst=10,hoffset=1)
TC
plot(TC)
summary(TC)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.