| Tides-package | R Documentation |
The tides package containes routines to calculate ecologicaly relevant characteristics of observed tides in intertidal systems.
| Package: | Tides |
| Type: | Package |
| Version: | 2.1.1 |
| License: | GNU Public License 2 or above |
Tom Cox (maintainer, <tom.cox@uantwerp.be>), Lennert Schepers (contributor, <lennert.schepers@uantwerp.be>)
TidalCharacteristics: the aggregate function returning several characteristics of the tides
## Not run:
##
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.