| print.Tides | R Documentation |
Print summary information of Tides-object
## S3 method for class 'Tides'
print(x, ...)
x |
Tides object (e.g. the result of TidalCharacteristics()) |
... |
Other arguments to be passed to print() |
Print inundation frequency, average inundation height, average inundation time, average dry time and number of tidal cycles in time series.
Tom Cox <tom.cox@uantwerp.be>, Lennert Schepers <lennert.schepers@uantwerp.be>
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.