summary.Tides: Summary of tidal characteristics

View source: R/Summary.R

summary.TidesR Documentation

Summary of tidal characteristics

Description

Outputs list of summary statistics of a Tides oabject

Usage

## S3 method for class 'Tides'
summary(object, ...)

Arguments

object

Tides object (e.g. the result of TidalCharacteristics)

...

Not used (Added for S3 method compatibility)

Value

A list containing:

IFsum:

Inundation frequency: see IF(). The proportion of high water tides higher than h0. A warning will be displayed when the inundation frequency is 100%.

nIndsum:

Inundations during time span, when the waterlevel > h0.

IHsum:

Average inundation height. A warning will be displayed when the inundation frequency is 100%.

IHcsum:

Average inundation height (per cycle).

Tunitssum:

time units

ITsum:

Average inundation time, in Tunitssum A warning will be displayed when h0 is never inundated

ITCsum:

Average inundation time (per cycle), in Tunitssum

ITMsum:

Maximal inundation time, in Tunitssum

DTsum:

Average dry time, in Tunitssum

DTCsum:

Average dry time (per cycle), in Tunitssum

DTMsum:

Maximal dry time, in Tunitssum

MHWsum:

Average high water. Note that the calculated HW and LW are always >= h0!

MLWsum:

Average low water. Note that the calculated HW and LW are always >= h0!

TRsum:

Average tidal range. Note that the calculated HW and LW are always >= h0!

nTCsum:

number of (tidal) cycles

nTCFsum:

number of full tidal cycles (used to measure averages per cycle)

nGsum:

number of gaps

GTsum:

total gaps time in mins

nTSsum:

number of continuous timeseries

TTNoGapsum:

total continuous timeseries time (without gaps, also tidal phases before and after gap are not included)

ITTsum:

total inundation time (without gaps, and also tidal phases before and after gap are not included)

DTTsum:

total dry time (without gaps, and also tidal phases before and after gap are not included)

IPsum:

proportion of total time inundated (without gaps, and also tidal phases before and after gap are not included)

DPsum:

DTTsum/TSsum # proportion of total time dry (without gaps, and also tidal phases before and after gap are not included)

Author(s)

Lennert Schepers <Lennert.Schepers@uantwerp.be>, Tom Cox <tom.cox@uantwerp.be>


Tides documentation built on July 21, 2026, 9:08 a.m.